"""

Wrapper for John Zweizig's NDS1/NDS2 library

"""
__author__       = "Leo Singer <leo.singer@ligo.org>"
__organization__ = ["LIGO", "California Institute of Technology"]
__copyright__    = "Copyright 2010, Leo Singer"
__version__      = "0.3.3"


import nds_ext
from nds_ext import channel_type, data_type, nds_version

class daq_iterator:
    def __init__(self, daq, start, stop, stride):
        self.__daq = daq
        self.__daq.request_data(start, stop, stride)
    def __iter__(self):
        return self
    def next(self):
        self.__daq.recv_next()
        return self.__daq.unpack()

class daq(nds_ext.daq):
    def __init__(self, host, port, version=None):
        if version is None:
            super(daq, self).__init__(host, port, nds_version.auto)
        else:
            super(daq, self).__init__(host, port, version)
        self.host = host
        self.port = port
    def seek(self, start, stop, stride):
	"""
	Begin playback, from GPS time start to GPS time end.
	Data will be provided in blocks of stride seconds.

	For online data, start and stop must be set to 0.

	Example usage::

	for data in daq.seek(0, 0, 1):
		print "Got %d channels" % len(data)
	"""
        return daq_iterator(self, start, stop, stride)
    def request_channels(self, channels):
        for channel in channels:
            self.request_channel(channel)

del nds_ext
